@@ -16,7 +16,7 @@
     "https://cran.r-project.org/package=ctrdata\n\n",
     "Please respect the requirements and the copyrights of the\n",
     "clinical trial registers when using their information. Call\n",
-    "ctrOpenSearchPagesInBrowser(copyright = TRUE) and visit\n",
+    "ctrOpenSearchPagesInBrowser(copyright = TRUE) and visit\n\n",
     "https://www.clinicaltrialsregister.eu/disclaimer.html\n",
     "https://classic.clinicaltrials.gov/ct2/about-site/terms-conditions#Use\n",
     "https://www.isrctn.com/page/faqs#usingISRCTN\n",
@@ -28,6 +28,15 @@
   # initialise
   initTranformers()
 
+  # inform user
+  if (.Platform$OS.type == "windows" &&
+      length(Sys.glob("c:\\cygw*\\bin\\bash.exe"))) {
+    packageStartupMessage(
+      "\nNote: Cygwin seems to be installed on the user's system.\n",
+      "This is no more needed for package ctrdata as of v1.16.0.\n",
+      "Users may chose to delete its folder (look for c:\\cygw*).\n")
+  }
+
   # return
   invisible()
 
